# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.3] - 2024-10-09

### Added
- Implicitly convert some timestamp fields to datetime

## [0.1.2] - 2024-10-09

### Added
- Add `userid` query parameter to `core_enrol_get_users_courses`

## [0.1.1] - 2024-10-09

### Added
- `MoodleLogin` to login with user/pass

## [0.1.0] - 2024-10-09

### Added
- Initial release
